@@ -28,7 +28,7 @@ OC.L10N.register(
     "You have deleted card {card} in list {stack} on board {board}" : "Smazali jste kartu {card} ve sloupci {stack} na tabuli {board}",
     "{user} has deleted card {card} in list {stack} on board {board}" : "{user} smazal(a) kartu {card} ve sloupci {board} na tabuli {board}",
     "You have renamed the card {before} to {card}" : "Přejmenovali jste kartu {before} na {card}",
-    "{user} has renamed the card {before} to {card}" : "{user} přejmenoval(a) {before} na {card}",
+    "{user} has renamed the card {before} to {card}" : "{user} přejmenoval(a) kartu {before} na {card}",
     "You have added a description to card {card} in list {stack} on board {board}" : "Přidali jste popis ke kartě {card} ve sloupci {stack} na tabuli {board}",
     "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} přidal(a) popis ke kartě {card} ve sloupci {stack} na tabuli {board}",
     "You have updated the description of card {card} in list {stack} on board {board}" : "Aktualizovali jste popis karty {card} ve sloupci {stack} na tabuli {board}",
@@ -73,7 +73,7 @@ OC.L10N.register(
     "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} vám přiřadil(a) kartu „%s“ na „%s“.",
     "The card \"%s\" on \"%s\" has reached its due date." : "U karty „%s“ z tabule „%s“ nastalo plánované datum dokončení.",
     "%s has mentioned you in a comment on \"%s\"." : "%s vás zmínil(a) v komentáři k „%s“.",
-    "{user} has mentioned you in a comment on \"%s\"." : "{user} vás zmínil(a) v komentáři v „%s“.",
+    "{user} has mentioned you in a comment on \"%s\"." : "{user} vás zmínil(a) v komentáři k „%s“.",
     "The board \"%s\" has been shared with you by %s." : "Uživatel %s vám nasdílel(a) tabuli „%s“.",
     "{user} has shared the board %s with you." : "{user} vám nasdílel(a) tabuli %s.",
     "No data was provided to create an attachment." : "Nebyla poskytnuta žádná data pro vytvoření přílohy.",
@@ -107,9 +107,17 @@ OC.L10N.register(
     "Select the board to link to a project" : "Vyberte tabuli kterou propojit s projektem",
     "Search by board title" : "Hledat podle názvu tabule",
     "Select board" : "Vybrat tabuli",
+    "Create a new card" : "Vytvořit novou kartu",
     "Select a board" : "Vybrat tabuli",
-    "Select a card" : "Vybrat tabuli",
+    "Select a list" : "Vyberte sloupec",
+    "Card title" : "Název karty",
     "Cancel" : "Storno",
+    "Creating the new card…" : "Vytváření nové karty…",
+    "\"{card}\" was added to \"{board}\"" : "„{card}“ bylo přidáno do „{board}“",
+    "Open card" : "Otevřít kartu",
+    "Close" : "Zavřít",
+    "Create card" : "Vytvořit kartu",
+    "Select a card" : "Vybrat kartu",
     "Select the card to link to a project" : "Vyberte kartu kterou propojit s projektem",
     "Link to card" : "Propojit s kartou",
     "File already exists" : "Soubor už existuje",
@@ -198,7 +206,7 @@ OC.L10N.register(
     "Remove due date" : "Odstranit termín",
     "Select Date" : "Vybrat datum",
     "Save" : "Uložit",
-    "The comment cannot be empty." : "Komentář je třeba vyplnit",
+    "The comment cannot be empty." : "Komentář je třeba vyplnit.",
     "The comment cannot be longer than 1000 characters." : "Délka komentáře může být nejvýše 1 000 znaků.",
     "In reply to" : "V odpověď na",
     "Reply" : "Odpovědět",
@@ -221,7 +229,6 @@ OC.L10N.register(
     "Archive card" : "Archivovat kartu",
     "Delete card" : "Smazat kartu",
     "Move card to another board" : "Přesunout kartu na jinou tabuli",
-    "Select a list" : "Vyberte sloupec",
     "Card deleted" : "Karta smazána",
     "seconds ago" : "před několika sekundami",
     "All boards" : "Všechny tabule",
@@ -231,7 +238,7 @@ OC.L10N.register(
     "Show boards in calendar/tasks" : "Zobrazit tabule v kalendáři/úkolech",
     "Limit deck usage of groups" : "Omezit využití deck na skupiny",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omezení nastavené pro Deck brání uživatelům, kteří nejsou součástí těchto skupin, ve vytváření vlastních tabulí. Nicméně i tak ale pořád budou moci pracovat na tabulích, které jsou jim nasdíleny.",
-    "Board details" : "Podrobnosti o desce",
+    "Board details" : "Podrobnosti o tabuli",
     "Edit board" : "Upravit tabuli",
     "Clone board" : "Klonovat tabuli",
     "Unarchive board" : "Vrátit tabuli zpět z archivu",
@@ -258,11 +265,13 @@ OC.L10N.register(
     "upcoming cards" : "nadcházející karty",
     "Link to a board" : "Propojit s tabulí",
     "Link to a card" : "Propojit s kartou",
+    "Create a card" : "Vytvořit kartu",
+    "Message from {author} in {conversationName}" : "Zpráva od {author} v {conversationName}",
     "Something went wrong" : "Něco se pokazilo",
     "Failed to upload {name}" : "Nepodařilo se nahrát {name}",
     "Maximum file size of {size} exceeded" : "Překročena nejvyšší umožněná velikost souboru {size}",
     "Error creating the share" : "Chyba při vytváření sdílení",
-    "Share with a Deck card" : "Sdílet kartu aplikace Deck",
+    "Share with a Deck card" : "Sdílet s kartou aplikace Deck",
     "Share {file} with a Deck card" : "Sdílet {file} s kartou aplikace Deck",
     "Share" : "Sdílet"
 },
