@@ -10,11 +10,12 @@ OC.L10N.register(
     "Can share" : "Can share",
     "Delete" : "Suprimir",
     "Edit" : "Modificar",
+    "Upload new files" : "Enviar fichièrs novèls",
     "Save" : "Salvar",
     "Reply" : "Respondre",
     "Update" : "Metre a jorn",
     "Description" : "Descripcion",
-    "seconds ago" : "i a qualques segondas",
+    "seconds ago" : "fa qualques segondas",
     "Shared with you" : "Shared with you",
     "Today" : "Uèi",
     "Tomorrow" : "Deman"
