@@ -107,9 +107,17 @@ OC.L10N.register(
     "Select the board to link to a project" : "选择要链接到一个项目的面板",
     "Search by board title" : "通过标题搜索面板",
     "Select board" : "选择面板",
+    "Create a new card" : "创建一张新卡片",
     "Select a board" : "选择一个面板",
-    "Select a card" : "选择一张卡片",
+    "Select a list" : "选择一个列表",
+    "Card title" : "卡片标题",
     "Cancel" : "取消",
+    "Creating the new card…" : "正在创建新卡片…",
+    "\"{card}\" was added to \"{board}\"" : "卡片 \"{card}\" 被添加到看板 \"{board}\"",
+    "Open card" : "打开卡片",
+    "Close" : "关闭",
+    "Create card" : "创建卡片",
+    "Select a card" : "选择一张卡片",
     "Select the card to link to a project" : "选择要链接到一个项目的卡片",
     "Link to card" : "链接到卡片",
     "File already exists" : "文件已存在",
@@ -221,7 +229,6 @@ OC.L10N.register(
     "Archive card" : "归档卡片",
     "Delete card" : "删除卡片",
     "Move card to another board" : "将卡片移到其他面板",
-    "Select a list" : "选择一个列表",
     "Card deleted" : "卡片被删除",
     "seconds ago" : "几秒前",
     "All boards" : "全部面板",
@@ -258,6 +265,8 @@ OC.L10N.register(
     "upcoming cards" : "即将到来的卡片",
     "Link to a board" : "链接到一个面板",
     "Link to a card" : "链接到一张卡片",
+    "Create a card" : "创建一张卡片",
+    "Message from {author} in {conversationName}" : "{conversationName} 会话中来自 {author} 的消息",
     "Something went wrong" : "发生了错误",
     "Failed to upload {name}" : "未能上传 {name}",
     "Maximum file size of {size} exceeded" : "文件容量已超过 {size} 的上限",
