@@ -143,12 +143,14 @@ class DeckProvider implements IProvider {
 		$params = $this->parseParamForLabel($subjectParams, $params);
 		$params = $this->parseParamForAssignedUser($subjectParams, $params);
 		$params = $this->parseParamForAcl($subjectParams, $params);
-		$params = $this->parseParamForChanges($subjectParams, $params, $event);
+		if ($subjectIdentifier !== ActivityManager::SUBJECT_CARD_UPDATE_STACKID) {
+			$params = $this->parseParamForChanges($subjectParams, $params, $event);
+		}
 		$params = $this->parseParamForComment($subjectParams, $params, $event);
 		$params = $this->parseParamForDuedate($subjectParams, $params, $event);
 
 		try {
-			$subject = $this->activityManager->getActivityFormat($subjectIdentifier, $subjectParams, $ownActivity);
+			$subject = $this->activityManager->getActivityFormat($language, $subjectIdentifier, $subjectParams, $ownActivity);
 			$this->setSubjects($event, $subject, $params);
 		} catch (\Exception $e) {
 		}
